==> apeman-ui-contrib-angular-locating-1.0.2.tgz: package/assets/src/services/ap-location-search.js <==
(function (ng) {
    /**
     * @ngdoc service
     * @module apeman-ui-contrib-angular-locating
     * @name apLocationSearch
     * @description Location search wrapper.
     */

    "use strict";

    ng
        .module('apeman-ui-contrib-angular-locating')
        .service('apLocationSearch', function ($location) {
            var s = this;
            /**
             * @ngdoc method
             * @name apLocationSearch#consume
             * @description Get location search with key and delete the key from search.
             * @param {string} key - Search key.
             * @returns {string} - Search value with the key.
             */
            s.consume = function (key) {
                var search = $location.search(),
                    val = search[key];
                s.delete(key);
                return val;
            };

            /**
             * @ngdoc method
             * @name apLocationSearch#delete
             * @description Delete search with pattern.
             * @param {string} key - Key to delete.
             */
            s.delete = function (key) {
                var search = $location.search();
                delete search[key];
                $location.search(search);
            };


            /**
             * @ngdoc method
             * @name apLocationSearch#deleteByPattern
             * @description Delete search with pattern.
             * @param {string|RegExp} pattern - Pattern to compare.
             */
            s.deleteByPattern = function (pattern) {
                var search = $location.search();
                Object.keys(search).forEach(function (key) {
                    var shouldDelete = key.match(pattern);
                    if (shouldDelete) {
                        delete search[key];
                    }
                });
                $location.search(search);
            };

            /**
             * @ngdoc method
             * @name apLocationSearch#get
             * @description Get search type.
             * @param {string} key - Key to search.
             * @returns {string|object} - Search value
             */
            s.get = function (key) {
                var search = $location.search();
                if (arguments.length == 0) {
                    return search;
                }
                return search[key];
            };

            /**
             * @ngdoc method
             * @name apLocationSearch#getByPattern
             * @description Get search by pattern
             * @param pattern
             * @returns {object} values.
             */
            s.getByPattern = function (pattern) {
                var search = $location.search(),
                    result = {};
                Object.keys(search).forEach(function (key) {
                    var shouldGet = key.match(pattern);
                    if (shouldGet) {
                        result[key] = search[key];
                    }
                });
                return result;
            };


            /**
             * @ngdoc method
             * @name apLocationSearch#update
             * @description Change search value.
             * @param {string} key - Key to set.
             * @param {string} val - Value to set.
             */
            s.update = function (key, val) {
                var values;
                if (arguments.length == 2) {
                    values = {};
                    values[key] = val;
                    s.update(values);
                    return;
                }
                values = arguments[0];
                var search = $location.search();
                Object.keys(values).forEach(function (key) {
                    search[key] = values[key];
                });
                $location.search(search);
            };
        });

})(angular);

==> apeman-ui-contrib-angular-locating-1.2.0.tgz: package/assets/src/services/ap-location-search.js <==
(function (ng) {
    /**
     * @ngdoc service
     * @module apeman-ui-contrib-angular-locating
     * @name apLocationSearch
     * @description Location search wrapper.
     */

    "use strict";

    ng
        .module('apeman-ui-contrib-angular-locating')
        .service('apLocationSearch', function ($location, apObjectNest) {
            var s = this;
            /**
             * @ngdoc method
             * @name apLocationSearch#consume
             * @description Get location search with key and delete the key from search.
             * @param {string} key - Search key.
             * @returns {string} - Search value with the key.
             */
            s.consume = function (key) {
                var search = $location.search(),
                    val = search[key];
                s.delete(key);
                return val;
            };

            /**
             * @ngdoc method
             * @name apLocationSearch#delete
             * @description Delete search with pattern.
             * @param {string} key - Key to delete.
             */
            s.delete = function (key) {
                var search = s.get();
                delete search[key];
                $location.search(search);
            };


            /**
             * @ngdoc method
             * @name apLocationSearch#deleteByPattern
             * @description Delete search with pattern.
             * @param {string|RegExp} pattern - Pattern to compare.
             */
            s.deleteByPattern = function (pattern) {
                var search = s.get();
                Object.keys(search).forEach(function (key) {
                    var shouldDelete = key.match(pattern);
                    if (shouldDelete) {
                        delete search[key];
                    }
                });
                $location.search(search);
            };

            /**
             * @ngdoc method
             * @name apLocationSearch#get
             * @description Get search type.
             * @param {string} key - Key to search.
             * @returns {string|object} - Search value
             */
            s.get = function (key) {
                var search = $location.search();
                if (arguments.length == 0) {
                    return search;
                }
                return search[key];
            };

            /**
             * @ngdoc method
             * @name apLocationSearch#getByPattern
             * @description Get search by pattern
             * @param pattern
             * @returns {object} values.
             */
            s.getByPattern = function (pattern) {
                var search = apObjectNest.expand($location.search() || {}),
                    result = {};
                Object.keys(search).forEach(function (key) {
                    var shouldGet = key.match(pattern);
                    if (shouldGet) {
                        result[key] = search[key];
                    }
                });
                return result;
            };


            /**
             * @ngdoc method
             * @name apLocationSearch#set
             * @description Change search value.
             * @param {string} key - Key to set.
             * @param {string} val - Value to set.
             */
            s.set = function (key, val) {
                var values;
                if (arguments.length == 2) {
                    values = {};
                    values[key] = val;
                    s.set(values);
                    return;
                }
                values = arguments[0];
                var search = apObjectNest.flatten($location.search());
                Object.keys(values).forEach(function (key) {
                    search[key] = values[key];
                });
                $location.search(search);
            };
        });

})(angular);
